parameters for the equations to predict discharge with water surface elevation based on observed stage-discharge relationships at each site
1 |
A tibble 39 x 9
-X (int) index
-sitename (chr) 5 character rivermile + side ex. 0034L = 3.4 mile on river left
-intecept (dbl) intercept for stage-discharge equation
-term1 (dbl) first term in polynomial equation relating stage to discharge
-term2 (dbl) second term in polynomial equation relating stage to discharge
-r.squared (dbl) the coefficient of determination for the stage-discharge measurments
the polynomial equation relating stage and discharge
-adjr.squared (dbl) coefficient of determination adjusted for the number of predictors in the model
-maxE (dbl) maximum elevation of stage-discharge observations, maximum elevation equation is valid for
-minE (dbl) minimum elevation of stage-discharge observations, minimum elevation equation is valid for
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.